@@ -1,5 +1,7 @@
 
 from odoo.tests.common import TransactionCase
+from odoo.addons.eleven_module.models import EleveModel
+from .no_exists import package
 
 # Even though astroid is not set as an external dependency, it should not fail,
 # because this is a test file
@@ -13,3 +15,9 @@ class TestModel(TransactionCase):
         super(TestModel, self).setUp()
         self.const = isinstance(astroid.Const, Const)
         self.bo = isinstance(astroid.BinOp, bo)
+
+    def method(self):
+        return package
+
+    def methodModel(self):
+        return EleveModel
